@@ -22,23 +22,15 @@ class RebalanceFailure(Exception):
     pass
 
 
-class RoutesExhausted(RebalanceFailure):
-    pass
-
-
-class RebalanceCandidatesExhausted(RebalanceFailure):
-    pass
-
-
 class NoRebalanceCandidates(RebalanceFailure):
     pass
 
 
-class RebalancingTrialsExhausted(RebalanceFailure):
+class NotEconomic(RebalanceFailure):
     pass
 
 
-class MultichannelInboundRebalanceFailure(RebalanceFailure):
+class RebalancingTrialsExhausted(RebalanceFailure):
     pass
 
 
@@ -76,6 +68,12 @@ class TemporaryChannelFailure(PaymentFailure):
         super().__init__()
 
 
+class TemporaryNodeFailure(PaymentFailure):
+    def __init__(self, payment):
+        self.payment = payment
+        super().__init__()
+
+
 class UnknownNextPeer(PaymentFailure):
     def __init__(self, payment):
         self.payment = payment
@@ -88,6 +86,12 @@ class FeeInsufficient(PaymentFailure):
         super().__init__()
 
 
+class IncorrectCLTVExpiry(PaymentFailure):
+    def __init__(self, payment):
+        self.payment = payment
+        super().__init__()
+
+
 class ChannelDisabled(PaymentFailure):
     def __init__(self, payment):
         self.payment = payment
